@@ -537,7 +537,7 @@ impl MemoryInstance {
     ///
     /// [`set`]: #method.get
     /// [`clear`]: #method.set
-    #[allow(clippy::clippy::needless_lifetimes)]
+    #[allow(clippy::needless_lifetimes)]
     pub fn direct_access<'a>(&'a self) -> impl AsRef<[u8]> + 'a {
         struct Buffer<'a>(Ref<'a, ByteBuf>);
         impl<'a> AsRef<[u8]> for Buffer<'a> {
@@ -558,7 +558,7 @@ impl MemoryInstance {
     ///
     /// [`get`]: #method.get
     /// [`set`]: #method.set
-    #[allow(clippy::clippy::needless_lifetimes)]
+    #[allow(clippy::needless_lifetimes)]
     pub fn direct_access_mut<'a>(&'a self) -> impl AsMut<[u8]> + 'a {
         struct Buffer<'a>(RefMut<'a, ByteBuf>);
         impl<'a> AsMut<[u8]> for Buffer<'a> {
